 MODULE interaction_droplets_ptq_mod

!------------------------------------------------------------------------------!
! Current revisions:
! -----------------
!
!
! Former revisions:
! -----------------
! $Id: interaction_droplets_ptq.f90 800 2011-12-21 18:13:51Z franke $
!
! 799 2011-12-21 17:48:03Z franke
! Bugfix: pt_d_t(k) was missing in calculation of pt_p
!
! RCS Log replace by Id keyword, revision history cleaned up
!
! Revision 1.1  2005/06/26 19:57:47  raasch
! Initial revision
!
!
! Description:
! ------------
! Release of latent heat and change of specific humidity due to condensation /
! evaporation of droplets.
!------------------------------------------------------------------------------!

    PRIVATE
    PUBLIC interaction_droplets_ptq

    INTERFACE interaction_droplets_ptq
       MODULE PROCEDURE interaction_droplets_ptq
       MODULE PROCEDURE interaction_droplets_ptq_ij
    END INTERFACE interaction_droplets_ptq
 
 CONTAINS


!------------------------------------------------------------------------------!
! Call for all grid points
!------------------------------------------------------------------------------!
    SUBROUTINE interaction_droplets_ptq

       USE arrays_3d
       USE cloud_parameters
       USE control_parameters
       USE indices

       USE pegrid

       IMPLICIT NONE

       INTEGER ::  i, j, k

 
       DO  i = nxl, nxr
          DO  j = nys, nyn
             DO  k = nzb_2d(j,i)+1, nzt
                q_p(k,j,i)  = q_p(k,j,i)  - ql_c(k,j,i)
                pt_p(k,j,i) = pt_p(k,j,i) + l_d_cp * ql_c(k,j,i) * pt_d_t(k)
             ENDDO
          ENDDO
       ENDDO

    END SUBROUTINE interaction_droplets_ptq


!------------------------------------------------------------------------------!
! Call for grid point i,j
!------------------------------------------------------------------------------!
    SUBROUTINE interaction_droplets_ptq_ij( i, j )

       USE arrays_3d
       USE cloud_parameters
       USE control_parameters
       USE indices

       USE pegrid

       IMPLICIT NONE

       INTEGER ::  i, j, k


       DO  k = nzb_2d(j,i)+1, nzt
          q_p(k,j,i)  = q_p(k,j,i)  - ql_c(k,j,i)
          pt_p(k,j,i) = pt_p(k,j,i) + l_d_cp * ql_c(k,j,i) * pt_d_t(k)
       ENDDO

    END SUBROUTINE interaction_droplets_ptq_ij

 END MODULE interaction_droplets_ptq_mod
